// 
// Module: Arfgen
// Author: Hassan Siddiqui
//
// Description: Main class for generating ARF
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: Arfgen.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */
#include <iostream>

/* SAS-specific */
#include "Xmm.h"
#include "param.h"
#include "Dal.h"
#include "Tracer.h"

/* Local */
#include "Arfgen.h"
#include "ArfDataServer.h"
#include "ArfTableIterator.h"
#include "SetBackScale.h"


void Arfgen::exec()
{
      
      PROC;
      
      // Open the arf dataset
      string arfsetname = stringParameter("arfset");
      errstr 
	<< "Opening arfset " << arfsetname << "..."
	<< Sas::message(Msg::App, Msg::Sparse);

      DataSet * arfset;

      if (booleanParameter("keeparfset")) {
         arfset = dataSetServer->
            open(stringParameter("arfset"), DataSet::Create);
      } else {
         arfset = dataSetServer->
            open(stringParameter("arfset"), DataSet::Temp);
      }
      //DataSet * arfset = dataSetServer->
   	   // open(stringParameter("arfset"), DataSet::Create);

      // Add the arf table to the dataset

      Table * arftable = arfset->addTable("SPECRESP", 
					  arfDataServer->ebins()->bins());

      // Add the attributes appropriate for an OGIP-compliant ARF
      
      *arftable->addAttribute("TELESCOP",    "mission/satellite name")                  = "XMM";
      
      *arftable->addAttribute("INSTRUME",    "instrument/detector name")                = Xmm::toString(arfDataServer->instrumentID());

      *arftable->addAttribute("FILTER",      "filter in use")                           = " ";
      
      *arftable->addAttribute("ARFVERSN",    "OGIP classification of FITS format")      = "1992a";
      
      *arftable->addAttribute("HDUCLASS",    "Format conforms to OGIP standard")        = "OGIP";
      
      *arftable->addAttribute("HDUCLAS1",    "dataset relates to spectral response")    = "RESPONSE";

      *arftable->addAttribute("HDUCLAS2",    "dataset is a spectral response matrix")   = "SPECRESP";

      *arftable->addAttribute("HDUVERS1",    "Obsolete - included for backwards compatibility")     = "1.0.0";

      *arftable->addAttribute("HDUVERS2",    "Obsolete - included for backwards compatibility")     = "1.1.0";

      *arftable->addAttribute("HDUVERS",    "the version of the HDUCLAS2 format in use")            = "1.1.0";

  
      // Set up the table iterator
      ArfTableIterator arftableiterator;

      // Run it
      arftableiterator.processEntireTable(arftable);

      // Clean up
      errstr 
	<< "Closing arfset " << arfsetname << "."
	<< Sas::message(Msg::App, Msg::Sparse);
      dataSetServer->close(arfset);

      /* Set the backscale value in the input spectrum if required */
      if (booleanParameter("setbackscale")) {
         SetBackScale::SetBackScale();
      }
  
      ENDPROC;

    } 
