// Module: PosWCS
//
// Author: Hassan Siddiqui
//
// Description:
//
// Reads in X/Y WCS from a given dataset.
//
// If the info in invalid/not present,
// the valid() method will return false.
//
// Modifications: See ChangeLog
//
// $Id: PosWCS.h,v 1.2 2009/09/03 13:19:51 aibarra Exp $

#ifndef PosWCS_H
#define PosWCS_H

/* SAS-specific */
#include "Dal.h"

/* Local classes */
#include "WCSConvertor.h"


class PosWCS
{
public:

  /* Read state from dataset */
  PosWCS( const DataSet * const set,
	  double default_ra,
	  double default_dec,
          double refpa,
          bool useodf );

  /* Destructor */
 ~ PosWCS();

  /* Returns a pointer to WCS object */
 /* AI gcc4 porting
  *   error: type qualifiers ignored on function return type
  *   => const removed
  */
 const WCSConvertor *  wcs() const;

  /* Returns the default dec,ra,pa */
  /* AI gcc4 porting
   * error: extra qualification ‘PosWCS::’ on member ‘xxx’
   */
   double refra() const;
   double refdec() const;
   double pa() const;

  /* Returns whether to use the ODF for attitude reconstruction */
   bool useODF() const;
  /* AI gcc4 porting
   * end
   */
private:

  bool _valid;

  double _refra;
  double _refdec;
  double _refpa;

  bool _useodf;

  const WCSConvertor * _wcs;
};

#endif
